@@ -163,7 +163,7 @@ class Postgres_Handler:
         
         #Iterates through the arguments adds the key to the column_name, and the value to the column_value
         for key, value in kwargs.items():
-            column_names_string += f'{key}s,'
+            column_names_string += f'{key},'
             column_values_string += f"%({key})s,"
             values_dict[key] = value
             
